# Features

- Automatically re-run the application when modifying the soruce.
- Deploy the application like Capistrano. it's powerful but simple.

# How to install

\$ pip3 install gat-tool

then you can use "gat init" command under the foler which you want to use.

# How to use

## Initialization

\$ gat init

It generates gat.yml and gat_my.py files.

### gat.yml

You can define the configure of the application and the server definition for the application deployment in this file.

### gat_my.py

You can define and expand the jobs for running and deployments.
